create database wrtts;

use wrtts;

create table user_status_list (
    usl_id      smallint NOT NULL PRIMARY KEY,
    usl_hidden  tinyint NOT NULL DEFAULT 0,
    usl_name    varchar(40) NOT NULL);

insert into user_status_list (usl_id, usl_hidden, usl_name) values (1, 0, 'Active');
insert into user_status_list (usl_id, usl_hidden, usl_name) values (1000, 1, 'Fired');

create table activity_status_list (
    asl_id      smallint NOT NULL PRIMARY KEY,
    asl_hidden  tinyint NOT NULL DEFAULT 0,
    asl_name    varchar(40) NOT NULL);

insert into activity_status_list (asl_id, asl_hidden, asl_name) values (1, 0, 'Active');
insert into activity_status_list (asl_id, asl_hidden, asl_name) values (1000, 1, 'Hidden');

create table project_status_list (
    psl_id      smallint NOT NULL PRIMARY KEY,
    psl_hidden  tinyint NOT NULL DEFAULT 0,
    psl_name    varchar(40) NOT NULL
    );

insert into project_status_list (psl_id, psl_hidden, psl_name) values (1, 0, 'Active');
insert into project_status_list (psl_id, psl_hidden, psl_name) values (1000, 1, 'Closed');

create table companies (
    c_id        int not null AUTO_INCREMENT primary key,
    c_name      varchar(200) not null,
    c_www       varchar(250),
    c_currency  char(7)
    );

create table users (
    u_id        int NOT NULL AUTO_INCREMENT PRIMARY KEY,
    u_timestamp timestamp,
    u_login     varchar(100),
    u_password  varchar(30),
    u_name      varchar(100),
    u_company_id int NULL,
    u_manager_id int NULL,                
    u_level     tinyint NOT NULL DEFAULT 0,
    u_active    smallint NOT NULL DEFAULT 1,
    u_rate      float(6,2) NOT NULL default '0.00',
    INDEX u_login_idx (u_login, u_active)
    );

create table invoice_header (
    ih_user_id    int(11) NOT NULL default 0,
    ih_number     varchar(20) default NULL,
    ih_addr_your  blob,
    ih_addr_cust  blob,
    ih_comment    varchar(255) default NULL,
    ih_tax        float(9,2) default '0.00',
    PRIMARY KEY (ih_user_id)
);

create table projects (
    p_id        int NOT NULL AUTO_INCREMENT PRIMARY KEY,
    p_timestamp timestamp,
    p_name      varchar(200),
    p_manager_id int NOT NULL,
    p_status    smallint NOT NULL DEFAULT 1,
    INDEX p_manager_idx (p_manager_id, p_status)
    );

create table activities (
    a_id        int NOT NULL AUTO_INCREMENT PRIMARY KEY,
    a_timestamp timestamp,
    a_name      varchar(200),
    a_manager_id int NOT NULL,
    a_status    smallint NOT NULL DEFAULT 1,
    a_project_id int NOT NULL default 0,
    INDEX a_manager_idx (a_manager_id, a_status)
    );

create table activity_log (
    al_timestamp timestamp,
    al_user_id  int NOT NULL REFERENCES users(u_id),
    al_date     date,
    al_from     time NULL,
    al_duration time,
    al_project_id int NOT NULL,
    al_activity_id int NOT NULL,
    al_comment varchar(200),
    PRIMARY KEY al_time_user_idx (al_timestamp, al_user_id),
    index al_date_idx (al_date),
    index al_user_id_idx(al_user_id ),
    index al_project_id_idx(al_project_id),
    index al_activity_id_idx(al_activity_id)
    );

